# vue-client

提供组件制作基础及部分通用组件。所有组件已经进行了全局注册，可直接使用。

## 第三方插件

* vue-strap：由于需要对vue-strap进行修改，在src目录下，导入了vue-stap源码，与vue-client源码同等处理。
* bootstrap：bootstrap源码，测试例子需要这些源码。OA等工程包含这些源码，不用复制。

## 目录结构

* androidtest: 手机模拟所需内容
* components: 提供的各种组件
* mixins: 方便调用的混合
* plugins: 系统提供的插件
* stores: 特殊的数据存储
* test: 单元测试基础
* util: 各类工具

## 全局内容

* [all](docs/all.md)：完成vue所有初始化工作。
* index.js：用于把相关模块对外公布，使用时，用`import { 模块名 } from 'vue-client'`即可引入。公布的模块有：
  - Selector
  - TreeMixin
  - PagedList
  - SelectStore
  - TreeList
  - DataModel
  - all
* client.less：自己扩充的基础样式，all里已经引入。

## 组件

* [AppBase](docs/AppBase.md)：提供应用基础，包括对话框，发送请求时提示正在工作等。
* [Busy](docs/Busy.md)：显示正在工作组件。
* [HttpBusy](docs/HttpBusy.md)：发送请求时，显示正在工作的组件。
* [MessageBox](docs/MessageBox.md)：显示提示框的组件。
* [Criteria](docs/Criteria.md)：查询条件生成器。
* [List](docs/List.md)：列表显示数据组件。
* [DataGrid](docs/DataGrid.md)：数据表格组件。
* [Tree](docs/Tree.md)：显示树状列表的组件。
* [GridTree](docs/GridTree.md)：表格树组件。
* [Pager](docs/Pager.md)：翻页组件。
* [CriteriaPaged](docs/CriteriaPaged.md)：复合组件，带查询条件的翻页显示数据组件。
* [Route](docs/Route.md)：路由组件，类似于浏览器里的一个页签。
* [Dynamic](docs/Dynamic.md)：动态页签组件。
* [FormPrint](docs/FormPrint.md): 连续打印列表中的数据。
* [PrintFile](docs/PrintFile.md): 折子打印的数据。
* [LoadParams](docs/LoadParams.md): 获取后台资源服务参数。
* [PrintTable](docs/PrintTable.md): 表格数据打印。
* [PrintElement](docs/PrintElement.md): 标签元素内容数据打印。
* [ReportExcel](docs/ReportExcel.md): 报表导Excel。
* [ReportPrint](docs/ReportPrint.md): 报表打印。
* [ReportSave](docs/ReportSave.md): 报表打印。
* [FileUpload](docs/FileUpload.md): 文件上传
* [ExportExcel](docs/ExportExcel.md): 配合业务逻辑完成Excel的导出
* [ImgSelf](docs/ImgSelf.md): 自定义图片查看组件
* [Slide](docs/Slide.md): 新产品弹出组件
* [CriteriaData](docs/CriteriaData.md): 查询条件并且去后台请求数据
* [Listener](docs/Listener.md):修改触发onerror事件的错误并POST到restful的log中去
* [GaoPaiYi](docs/GaoPaiYi.md):提供高拍仪拍照上传功能的组件。

## 插件

* [MessageBox](docs/MessageBox.md)：提供提醒对话框显示功能。
* [HttpStore](docs/MessageBox.md)：提供后台http请求功能。
* [Partial](docs/MessageBox.md)：提供片段支持。
* [Route](docs/Route.md)：提供路由功能。
* [GetParams](docs/GetParams.md)：提供获取指定参数的功能。

## 混合

* [Selector](docs/Selector.md)：对选择提供支持。
* [TreeMixin](docs/TreeMixin.md)：对树的操作提供支持。

## stores

* [SelectStore](docs/Selector.md)：对选中的数据进行存储。
* [PagedList](docs/PagedList.md)：提供分页列表数据处理。
* [TreeList](docs/TreeList.md)：提供树数据处理。
* [DataModel](docs/DataModel.md): 提供一般数据处理。
* [AppData](docs/AppData.md)：提供存储从资源服务中获取到的参数。

## 测试

所有组件均可单独测试，每个测试例子按如下目录结构组织

examples
>List
>>index.html
>>main.js
>>App.vue
>>辅助组件.vue

通过List.html进行访问

## 测试例子

* Partial：
对Partial进行测试，测试Partial的各种组合能力。
* Busy：
测试Busy组件。通过按钮，测试Busy状态。
* MessageBox：
对MessageBox进行测试，按下确定，或者取消按钮后，显示按下的按钮。
* HttpStore:
对HttpStore进行测试，按钮按下后，发送错误请求，在控制台显示请求结果。
* AppBase：
对AppBase进行测试，发送错误请求，弹出错误对话框。
* Criteria：
对查询条件组件进行测试，点击查询，显示产生的条件。
* List：
对List进行测试，用程序产生10000条数据，测试List组件性能。
* DataGrid：
对数据表格进行测试，不从后台获取数据，直接显示给定数据。
* Tree：
对树进行测试，不从后台获取数据，直接显示给定数据。
* GridTree：
对表格树进行测试，不从后台获取数据，直接显示给定数据。
* Pager：
对翻页组件进行测试，不从后台获取数据，直接显示给定数据。
* PagedList：
对PagedList模型进行测试，包括与 List, Tree, DataGrid, GridTree 等组件的结合。
* CriteriaPaged：
对带查询条件的翻页列表进行测试，从后台获取数据，每条数据可以删除。列表部分包括：List, Tree, DataGrid, GridTree
* DataForm：对表单进行完整测试，表单不需要组件。内容有：
  - 可以把数据提交后台，提交后台的数据可以通过左边的查询分页组件进行查询。
  - 查询出来的数据，当选中时，可以删除。
  - 左边查询分页组件支持：DataGrid, GridTree。不同查询组件放在tab页中。
  - 表单组件的输入数据可以进行校验。
* Layout：对基于弹性盒模型的布局进行测试。
* Report: 对报表进行测试。
* PrintFile:
对折子打印进行测试，从后台获取数据，打印到折子上。
* PrintData:
打印组件，查询界面做打印时使用
* PrintTable:
对表格连续打印进行测试，从后台获取数据。
* ReportExcel:
对报表导出未Excel、报表打印进行测试和报表保存进行测试，不从后台获取数据，直接从界面根据传入的id获取导出的内容。
* VSelect:
对从后台获取参数和下拉选择进行测试，从后台获取到多有的参数，通过插件提供的功能获取到指定的内容，并显示的下拉选项中。
* ExportExcel：
对文件上传和导Excel进行测试，导Excel分为导出指定字段和全部字段，
* ImgSelf：
可以单击图片全屏查看，并且提供放大缩小，旋转等功能
* Slide：
正常情况下隐藏，当isOpen为true时，自动从边界滑出
* CriteriaData：
对根据查询条件取后台取数据组件进行测试，点击查询，显示产生的条件，并且去后台请求数据
* Listener
修改触发onerror事件的错误并POST到restful的log中去

## 版本发布
运行npm run release发布版本。
