var express = require('express')
var webpack = require('webpack')
var config = require('./webpack.dev.conf')
var proxyMiddleware = require('http-proxy-middleware')
var httpProxy = require('http-proxy')

var app = express()
var compiler = webpack(config)
var proxy = httpProxy.createProxyServer()

// Define HTTP proxies to your custom API backend
// https://github.com/chimurai/http-proxy-middleware
var proxyTable = {
  '/rs': {
    target: 'http://192.168.50.222:7000/ldap'
  }
  // '/rs/weixin': {
  //   target: 'http://127.0.0.1:8081'
  // },
}

var devMiddleware = require('webpack-dev-middleware')(compiler, {
  publicPath: config.output.publicPath,
  stats: {
    colors: true,
    chunks: false
  }
})

var hotMiddleware = require('webpack-hot-middleware')(compiler)
// force page reload when html-webpack-plugin template changes
compiler.plugin('compilation', function (compilation) {
  compilation.plugin('html-webpack-plugin-after-emit', function (data, cb) {
    hotMiddleware.publish({ action: 'reload' })
    cb()
  })
})

// proxy api requests
Object.keys(proxyTable).forEach(function (context) {
  var options = proxyTable[context]
  if (typeof options === 'string') {
    options = { target: options }
  }
  app.use(proxyMiddleware(context, options))
})

// handle fallback for HTML5 history API
app.use(require('connect-history-api-fallback')())

// serve webpack bundle output
app.use(devMiddleware)

// enable hot-reload and state-preserving
// compilation error display
app.use(hotMiddleware)

// serve pure static assets
app.use('/static', express.static('./static'))

// app.all('/rs/*', function (req, res) {
//   proxy.web(req, res, {
//     target: 'http://127.0.0.1:8081/reports'
//   })
// })

// app.all('/rs/*', function (req, res) {
//   proxy.web(req, res, {
//     target: 'http://127.0.0.1:8081/ldap'
//   })
// })
// app.all('/excel/*', function (req, res) {
//   proxy.web(req, res, {
//     target: 'http://127.0.0.1:8081/charge'
//   })
// })



app.all('/rs/*', function (req, res) {
  console.log('上传文件')
  proxy.web(req, res, {
    target: 'http://127.0.0.1:8081'
  })
})


// app.all('/rs/*', function (req, res) {
//   proxy.web(req, res, {
//     target: 'http://127.0.0.1:82/charge'
//   })
// })

// app.all('/*', function (req, res) {
//   proxy.web(req, res, {
//     target: 'http://127.0.0.1:82'
//   })
// })
// app.all('/rs/user', function (req, res) {
//   proxy.web(req, res, {
//     target: 'http://127.0.0.1:82'
//   })
// })

module.exports = app.listen(8084, function (err) {
  if (err) {
    console.log(err)
    return
  }
  console.log('Listening at http://localhost:8084')
})
