## 注意事项
1. 在阅读界面制作范例之前，请优先阅读界面制作规范，界面制作规范对整体布局有详细说明。
2. 本文所给的范例主要是从bootstrap中抽取出来经常使用的控件，如与bootstrap有冲突，以bootstrap为准。
3. 对于本文中未作出范例或范例错误，请及时通知范例制作人员进行添加或修改。
4. 所有范例全部放在测试用例Sample中，如需查看，请将vue-client运行起来，在网页中打开Sample即可。
5. 本范例中并未对表格和左侧树做出范例，因为表格和树样式都由基础组件决定，对于表格不允许自己重写表格组件，如有特殊需求，请商讨后再做决定

## 表单校验状态（ValidatorSample.vue）
- Bootstrap 对表单控件的校验状态，如 error、warning 和 success 状态，都定义了样式。使用时，添加 .has-warning、.has-error 或 .has-success 类到这些控件的父元素即可。任何包含在此元素之内的 .control-label、.form-control 和 .help-block 元素都将接受这些校验状态的样式。<code>&lt;input&gt;</code>
- 还可以针对校验状态为输入框添加额外的图标。只需设置相应的 .has-feedback 类并添加正确的图标即可。

## 表单样式（FormSample.vue）

1. 基本实例
- 单独的表单控件会被自动赋予一些全局样式。所有设置了 .form-control 类的 <code>&lt;input&gt;</code>、<code>&lt;textarea&gt;</code> 和 <code>&lt;select&gt;</code> 元素都将被默认设置宽度属性为 width: 100%;。 将 label 元素和前面提到的控件包裹在 .form-group 中可以获得最好的排列。

  <form role="form">
    <div class="form-group">
      <label for="exampleInputEmail1">Email address</label>
      <input type="email" class="form-control" id="exampleInputEmail1" placeholder="Enter email">
    </div>
    <div class="form-group">
      <label for="exampleInputPassword1">Password</label>
      <input type="password" class="form-control" id="exampleInputPassword1" placeholder="Password">
    </div>
    <div class="form-group">
      <label for="exampleInputFile">File input</label>
      <input type="file" id="exampleInputFile">
      <p class="help-block">Example block-level help text here.</p>
    </div>
    <div class="checkbox">
      <label>
        <input type="checkbox"> Check me out
      </label>
    </div>
    <button type="submit" class="btn btn-default">Submit</button>
  </form>

**注意：不要将表单组直接和输入框组混合使用。建议将输入框组嵌套到表单组中使用**

2. 表单与栅格系统配合使用(水平排版)
- 对于pc端，可以在表单中利用栅格系统实现更好的布局，在最外层添加.form-horizontal，更好控制。
```html
<form class="form-horizontal">
  <caption><h1 align="center">水平排版样式</h1></caption>
  <div class="form-group">
    <label for="f_username" class="col-sm-1 control-label col-sm-offset-1 ">用户姓名：</label>
    <div class="col-sm-2">
        <input type="text"  v-model="model.f_username" class="form-control" id="f_username" placeholder="用户姓名">
    </div>

    <label for="f_userid" class="col-sm-1 control-label">用户编号：</label>
    <div class="col-sm-2">
        <input type="text"  v-model="model.f_userid" class="form-control" id="f_userid" placeholder="用户编号">
    </div>

    <label for="f_apartment" class="col-sm-1 control-label">门牌号：</label>
    <div class="col-sm-2">
        <input type="text" v-model="model.f_apartment" class="form-control" id="f_apartment" placeholder="门牌号">
    </div>
  </div>
</form>
```
**注意：必须输入控件设置 label 标签，并且在label标签内是用 .control-label样式，以获得右对齐的样式**

3. 内联表单
- 为元素添加 .form-inline 类可使其内容左对齐并且表现为 inline-block 级别的控件。只适用于视口（viewport）至少在 768px 宽度时（视口宽度再小的话就会使表单折叠）。
- 对于需要验证的输入控件，并对保存按钮有影响，不建议使用v-if直接隐藏按钮，而是控制按钮的禁用与否获得更好的界面样式。
```html
<validator name='v'>
  <div class="form-inline ">
    <div class="form-group auto"
      v-bind:class="{ 'has-warning has-feedback': $v.lastinputdate.required, 'has-success has-feedback': !$v.lastinputdate.required }">
      <label class="control-label" for="lastinputdate">最后抄表日期:</label>
      <input type="text" class="form-control" id="lastinputdate"
      v-model="model.lastinputdate" v-validate:lastinputdate='{ required: true }' title="不能为空">
      <span v-if="$v.lastinputdate.required" class="glyphicon glyphicon-warning-sign form-control-feedback"></span>
      <span v-else class="glyphicon glyphicon-ok form-control-feedback"></span>
      <!-- <div v-if="$v.lastinputdate.required" class="alert alert-warning" role="alert">此字段不能为空</div> -->
    </div>
    <button type="button" class="btn btn-success" @click="confirm()" :disabled="!$v.valid">
       <span class="glyphicon glyphicon-floppy-disk"></span> 保存
    </button>
  </div>
</validator>
```
**注意：表单样式，并不只限于<form>中，在其他控件中也可使用，规则不变**
