import Vue from 'vue'

// 注册一个全局的输入过滤特殊字符指令，用于过滤特殊字符 在元素上使用v-filter即可
Vue.directive('filter', {
  twoWay: true,
  bind: function () {
    this.handler = function () {
      var reg = new RegExp(/[ ,\`,\~,\!,\@,\#,\$,\%,\^,\+,\*,\￥,\&,\\,\/,\?,\|,\:,\.,\<,\>,\{,\},\(,\),\',\;,\=,\"]/)
      this.el.value = this.el.value.replace(reg, '')
      this.set(this.el.value)
    }.bind(this)
    this.el.addEventListener('input', this.handler)
  },
  unbind: function () {
    this.el.removeEventListener('input', this.handler)
  }
})
// 注册一个只能输入数字
Vue.directive('numfilter', {
  twoWay: true,
  bind: function () {
    this.handler = function () {
      this.el.value = this.el.value.replace(/[^\d]/g,'')
      this.set(this.el.value)
    }.bind(this)
    this.el.addEventListener('input', this.handler)
  },
  unbind: function () {
    this.el.removeEventListener('input', this.handler)
  }
})

// 注册一个全局自定义指令 next-el, 回车切换焦点，在元素上使用v-next-el="abc",给要切换到的元素上使用v-el: abc
Vue.directive('next-el', {
  bind: function () {
  },
  update: function (value) {
    this.handler = function () {
      // if (this.expression.includes('id')) {
      let el = null
      if (value) {
        el = document.getElementById(value.id)
      } else {
        el = this.vm.$els[this.expression]
      }
      if (el) {
        el.focus()
      }
    }.bind(this)
    this.el.addEventListener('keyup', function (event) {
      // console.log(event)
      if (event.keyCode === 13) {
        this.handler()
      }
    }.bind(this))
  },
  unbind: function () {
    this.el.removeEventListener('keyup', this.handler)
  }
})

// 保留小数位数，默认保留两位
Vue.directive('scale', {
  twoWay: true,
  update: function (value) {
    let fixed = 2
    let val = value
    let strs = this.expression
    if (typeof value === 'object') {
      val = value[0]
      fixed = value[1] || 2
      strs = this.expression.substring(1, this.expression.length - 1).split(',')[0]
    }
    if (val && val.toString().split('.')[1] && (val.toString().split('.')[1].length + 1) > fixed) {
      this.el.value = (val - 0).toFixed(fixed)
      eval(`this.vm.${strs} = ${this.el.value}`)
    }
  }
})

// 注册一个页面加载自动获取焦点指令，暂没有实现完成，调试开发中
Vue.directive('focus', {
  bind: function () {
    this.el.focus()
  }
})


//提示框
Vue.directive('title', {
  bind:function() {
    // 使用 const 声明一个只读的常量，其值是需要监听的事件类型列表
    const events = ['mouseenter','mouseleave','click']
    console.log(this,'dasd')
    // 声明一个处理器，以根据不同的事件类型传不同的参数
    const handler = (event) => {
      if (event.type === 'mouseenter') {
        // 显示一个提示框
        showTitle(this.el, this.expression)
      } else {
        // 隐藏一个提示框
        showTitle()
      }
    }

    // 在 el 元素上添加事件监听
    events.forEach((event) => {
      this.el.addEventListener(event, handler, false)
    })

    // 在 el 元素上添加一个属性，以在其他钩子进行访问
    this.el.destroy = () => {
      // 移除 el 元素上的事件监听
      events.forEach((event) => {
        this.el.removeEventListener(event, handler, false)
      })
      // 移除 el 元素上的 destroy
      this.el.destroy = null
    }
  },
  // unbind:function() {
  //   // 移除事件监听和数据绑定
  //   this.el.destroy()
  // }

})

function showTitle(el, title) {
  const popover = getPopover()
  const popoverStyle = popover.style

  if (title === undefined) {
    popoverStyle.display = 'none'
  } else {
    const elRect = el.getBoundingClientRect()
    const elComputedStyle = window.getComputedStyle(el, null)
    const rightOffset = parseInt(elComputedStyle.getPropertyValue('padding-right')) || 0
    const topOffset = parseInt(elComputedStyle.getPropertyValue('padding-top')) || 0

    popoverStyle.visibility = 'hidden'
    popoverStyle.display = 'block'
    console.log(popover,'测试')
    var s=title.toString().split('*')
    var context=''
    for(var i=0;i<s.length;i++){
      if(i%2==1){
        context=context+'<span style="color: red">'+s[i]+'</span>'
      }else {
        context=context+s[i]
      }
    }
    console.log(elRect,'asfda')
    console.log(elComputedStyle,'asfd1a')

    popover.querySelector('.popover-content').innerHTML = context
    popoverStyle.left = elRect.left - popover.offsetWidth / 2 + (el.offsetWidth - rightOffset) / 2 + 'px'
    if(elRect.top>800){
      if(popover.className.indexOf('top')<0){
        popover.className=popover.className+' top'
      }
      popoverStyle.top = elRect.top - popover.offsetHeight + topOffset + 'px'
    }else {
      if(popover.className.indexOf('bottom')<0){
        popover.className=popover.className+' bottom'
      }
      popoverStyle.top = elRect.top + elRect.height  + 'px'
    }
    console.log(popover.className)
    popoverStyle.display = 'block'
    popoverStyle.visibility = 'visible'
    popoverStyle.height = 'auto'
  }
}

function getPopover() {
  let popover = document.querySelector('.title-popover')

  if (!popover) {
    const tpl = `
      <div class="popover title-popover  fade in" style="position:fixed;">
        <div class="arrow"></div>
        <div class="popover-content"></div>
      </div>
    `
    const fragment = document.createRange().createContextualFragment(tpl)

    document.body.appendChild(fragment)
    popover = document.querySelector('.title-popover')
  }

  return popover
}


