export default {
  install (Vue, options) {
    // 修改vue的钩子调用，以便ready钩子支持promise
    Vue.prototype._callHook = function (hook) {
      this.$emit('pre-hook:' + hook);
      var handlers = this.$options[hook];
      if (handlers) {
        for (var i = 0, j = handlers.length; i < j; i++) {
          let result = handlers[i].call(this);
          if (hook === 'ready' && result && (result instanceof Promise)) {
            // 把promise添加到自己及父的_promises中
            this._preLoadAsyncReady(result)
          }
        }
        // 调用promises处理过程
        this._processAsyncReady()
      }
      this.$emit('hook:' + hook);
    }

    /**
     * 把promise添加到自己及父组件的promise组中，以便ready结束后产生'ready'事件
     * @param promise
     * @private
     */
    Vue.prototype._preLoadAsyncReady = function (promise) {
      // 给所有父组件添加自身的Promise
      let parent = this
      while (parent) {
        if (!parent._promises) {
          parent._promises = []
        }
        parent._promises.push(promise)
        parent = parent.$parent
      }
    }

    /**
     * 处理异步ready过程，找到自身及所有子的Promise，当所有Promise都完成后，对外发布ready事件，有一个失败，在对外发布error事件
     */
    Vue.prototype._processAsyncReady = function () {
      if (this._promises) {
        return Promise.all(this._promises).then(() => {
          // 清空本次promise
          this._promises = []
          this.$emit('ready')
        }).catch((error) => {
          // 清空本次promise
          this._promises = []
          this.$emit('error', error)
        })
      }
    }
  }
}
