import Vue from 'vue'
import co from 'co'

// post执行过程
let postGen = function * (method, url, data, self) {
  try {
    let dataRet = yield HttpBatch.http(method, url, data)
    // yield Vue.showMessage()
    self.busy = false
    HttpBatch.successNum++
    Vue.showBatchAlert('批量操作成功', 'success', 2000)
    return dataRet
  } catch (error) {
    // yield Vue.showMessage()
    self.busy = false
    HttpBatch.failedNum++
    Vue.showBatchAlert(`错误状态：${error.status}，错误内容：${error.data}`, 'danger', 0)
    throw error
  }
}

let HttpBatch = {
  // 成功条数
  successNum: 0,
  // 失败条数
  failedNum: 0,
  // 等待运行的http队列
  https: [],

  install (Vue, options) {
    // 给Vue增添post方法
    Vue.batchpost = Vue.prototype.$batchpost = function (url, data) {
      Vue.console.info(`post：${url}`, 'HttpBatch')
      let gen = postGen('POST', url, data, this)
      return co(gen)
    }
  },

  // 请求返回后的处理过程
  httpEnd () {
    // 从等待发送队列中获取一个未发送的请求，进行发送
    if (this.https.length > 0) {
      let send = this.https.splice(0, 1)[0]
      this.http(send.method, send.url, send.body).then(
        (response) => send.resolve(response)
      ).catch(
        (response) => send.reject(response)
      )
    }
  },

  // 处理http请求
  http (method, url, body) {
    return new Promise((resolve, reject) => {
      if (this.busy === false) {
        this.busy = true
        // 提示信息批量操作正在进行中
        Vue.showBatchAlert('批量操作中，请耐心等待...', 'info', 0)
        // 没有body，发送空对象
        if (!body) {
          body = {}
        }

        let that = this
        var xhr = new XMLHttpRequest()
        xhr.onreadystatechange = function () {
          if (xhr.readyState === 4) {
            if ((xhr.status >= 200 && xhr.status < 300) || xhr.status === 304) {
              that.httpEnd()
              resolve(xhr.responseText)
            } else {
              that.httpEnd()
              reject(xhr.statusText)
            }
          }
        }
        xhr.open(method, url, true)
        xhr.send(JSON.stringify(body))
      } else {
        // 将发送请求放到待发送队列中
        Vue.console.info(`put：${JSON.stringify(body)}`, 'HttpBatch')
        this.https.push({method, url, body, resolve, reject})
      }
    })
  }
}

// HttpBatch是否正在工作
Vue.set(HttpBatch, 'busy', false)

export default HttpBatch
