import Vue from 'vue'

export default {
  activate (done) {
    // 父为路由组件，组件切换进来时，获取标题，把标题设置到路由组件的标题，同时把参数传递给切换进来的组件
    if (this.$parent && this.$parent.$options.name === 'route') {
      let title = this.$options.title
      if (process.env.NODE_ENV !== 'production' && !title) {
        let error = `组件缺少title：${this.$options.name}`
        throw error
      }
      this.$parent.setTitle(title)

      // 给组件传递参数
      let props = this.$parent.top().props
      Object.assign(this, props)
    }
    done()
  },
  methods: {
    // name - 路由到的组件名
    // props - 给路由到的组件传递的参数
    // self - 在哪里路由：self - 自己，tab - 界面上的tab
    // resoved - 返回时的回调函数
    $goto (name, props = {}, self = 'self', resoved = null) {
      // 如果路由到自己或者到外面的tab页，给父自己发送消息
      if (self === 'self' || self === 'tab') {
        this.$dispatch('route', name, props, self, resoved)
      } else {
        // 否则，调用指定路由器的初始化路由方法
        // console.log('route: ' + self)
        // 路由到指定的路由器
        let route = Vue.routes[self]
        route.init(name, props)
      }
    },
    // 返回
    // 返回时的参数
    $back (param = null) {
      this.$dispatch('back', param)
    },
    // 关闭页签 自己添加
    $removeTab (name, props = {}, self = 'self', resoved = null) {
      // console.log('routejs中接受到的name为：', name)
      this.$dispatch('remove-tab', name, props, self, resoved)
    }
  }
}
