import Vue from 'vue'
const VueLogger = {
  allowGadgets : function (gadget) {
    if(gadget) {
      if (Array.isArray(gadget))
        this.allowedGadgets = gadget
      else
        this.allowedGadgets = [gadget]
    } else {
      this.allowedGadgets = false
    }
  }

}

VueLogger.install = function (Vue) {
  const logger = {
    dev: Vue.config.debug,
    levels: ['log', 'warn', 'info', 'error']
  }

  for (const level of logger.levels) {
    logger[level] = function () {
      // 如果设置了静默，所有得log将都不打印
      if (Vue.config.silent) return
      if (!logger.dev || typeof console === 'undefined') return
      let args = Array.from(arguments)
      let name
      if(this.constructor.name === 'VueComponent' && this.$options) {
        name = this.$options.name
      } else {
        name = args[args.length-1]
        args.splice(-1)
      }
      //if allowedGadgets set
      if(VueLogger.allowedGadgets && VueLogger.allowedGadgets.length > 0) {
        if(VueLogger.allowedGadgets.indexOf(name) != -1) {
          args.unshift(`[${name} :: ${level}]`)
          console[level].apply(console, args)
        }
      }
      else {
        args.unshift(`[${name} :: ${level}]`)
        console[level].apply(console, args)
      }
    }
    Vue.prototype[`$${level}`] = logger[level]
  }
  Vue.prototype.$console = logger
  Vue.console = logger
  Vue.allowGadgets = VueLogger.allowGadgets
}

export default VueLogger
