import Vue from 'vue'
import * as Util from '../util/Util'
import co from 'co'
import {alert} from "../vue-strap/src/main";

// 为进行Android组件测试所做
export default {
  // 作为vue插件安装
  install (Vue, options) {
    Vue.androidUtil = Vue.prototype.$androidUtil = this
    window.iosApp = {
      __this__ : null,
      __callback__ : null
    }
  },

  // 是否安卓运行环境
  isAndroid: false,

  // 是否测试环境
  isTest: false,

  // 是否允许安卓调试
  isAndroidDebug: false,

  // 代理转发url
  proxyUrl: '',

  // 模拟平板端环境，登陆后设置
  context: {
    version: 0
  },

  // 设置定时器对应的业务逻辑
  // time定时间隔，单位毫秒
  // data定时提取时，要传context等参数
  timeout (userName, time) {
    if (this.isTest) {
      if (!this.context.cc_base_url) {
        this.context.cc_base_url = this.getProxyUrl()
      }
      if (userName) {
        this.context.f_repairman_id = userName
      }
      let data = {
        data: {},
        context: this.context
      };
      // 调用服务端业务逻辑
      return Vue.resetpost('AndroidRest/rs/logic/定时提取', data).then((res) => {
        // 设置新版本
        if (res.data.version) {
          this.context.version = res.data.version
        }
      })
    }
  },

  // 查询本地数据
  path (params) {
    if (this.isTest) {
      return Vue.resetpost(`AndroidRest/rs/path/${params.alias}`, {data: params.data})
    } else {
      if(navigator.userAgent.match('iPad') || navigator.userAgent.match('iPhone')){
        return JSON.parse(window.prompt("path",JSON.stringify({'alias': params.alias, 'data': params.data})));
      } else {
        return HostApp.path({'alias': params.alias, 'data': params.data})
      }
    }
  },

  alert: function (msg) {
    if (!this.isTest) {
      if(navigator.userAgent.match('iPad') || navigator.userAgent.match('iPhone')) {
        window.prompt("alert", "延期申请成功");
      } else {
        HostApp.alert('延期申请成功')
      }
    }
  },

  // 获取反向代理的url
  getProxyUrl () {
    // 如果是安卓界面，直接返回
    let isAndroid = navigator.userAgent.match('Android');
    if (isAndroid) {
      return HostApp.getProxyUrl().data
    }
    if(navigator.userAgent.match('iPad') || navigator.userAgent.match('iPhone')){
      return JSON.parse(window.prompt("getProxyUrl","")).data;
    }
    if (this.isTest) {
      return this.proxyUrl
    }
    // pc运行界面
    return ''
  },

  // 输出调试信息到服务器上，用于真机调试
  log (msg) {
    if (this.isAndroidDebug) {
      Vue.post(`${this.getProxyUrl()}/rs/logic/androidLog}`, {data: msg}, {resolveMsg: null, rejectMsg: null})
    }
  },

  // 读卡
  read () {
    if (this.isTest) {
      return {
        code: 200,
        msg: {
          CardID: '10312669'
        }
      }
    }
    if(navigator.userAgent.match('iPad') || navigator.userAgent.match('iPhone')){
      return JSON.parse(window.prompt("read",""));
    } else {
      return HostApp.read()
    }
  },

  // 打印
  print (content) {
    if (this.isTest) {
      // 把打印内容发送到服务器上
      this.log(`打印：${content}`)
    } else {
      if(navigator.userAgent.match('iPad') || navigator.userAgent.match('iPhone')){
        window.prompt("print",content);
      } else {
        HostApp.print(content)
      }
    }
  },
  //获取平板端文件全路径
  getFullFileName(fileName) {
    if (this.isTest)
      return fileName;
    else
    if(navigator.userAgent.match('iPad') || navigator.userAgent.match('iPhone')){
      return JSON.parse(window.prompt("getFullFileName",fileName)).data;
    } else {
      return HostApp.getFullFileName(fileName).data
    }
  },
  // 调用业务逻辑
  bzLogic (logic, data) {
    if (this.isTest) {
      let sendData = {
        data: data,
        context: this.context,
      };
      // 调用android模拟业务逻辑
      return Vue.http.post(`AndroidRest/rs/logic/${logic}`, sendData)
    } else {
      if(navigator.userAgent.match('iPad') || navigator.userAgent.match('iPhone')){
        let result = JSON.parse(window.prompt("bzLogic",JSON.stringify({'logic': logic, 'data': data})));
        return result;
      } else {
        // 调用本地业务逻辑保存数据
        let param = {
          'logic': logic,
          'data': data
        }
        return HostApp.bzLogic(param)
      }
    }
  },
  // 调用业务逻辑
  syncBzLogic (logic, data) {
    if (this.isTest) {
      let sendData = {
        data: data,
        context: this.context,
      };
      // 调用android模拟业务逻辑
      return Vue.http.post(`AndroidRest/rs/logic/${logic}`, sendData)
    } else {
      if(navigator.userAgent.match('iPad') || navigator.userAgent.match('iPhone')){
        let result = JSON.parse(window.prompt("bzLogic",JSON.stringify({'logic': logic, 'data': data})));
        return result;
      } else {
        // 调用本地业务逻辑保存数据
        let subLength=800
        let param = {
          'logic': logic,
          'data': data
        }
        let params=JSON.stringify(param)
        for(let i=0;i<params.length;i+=subLength){
          HostApp.param_cache(params.substr(i,subLength))
        }
        return HostApp.syncBzLogic()
      }
    }
  },

  // 设置登陆人
  setPreference (field, value) {
    if (!this.isTest) {
      if(navigator.userAgent.match('iPad') || navigator.userAgent.match('iPhone')){
        window.prompt("setPreference",field+" "+value);
      } else {
        HostApp.setPreference(field, value)
      }
    } else {
      this.context[field] = value
    }
  },
  // 获取账号密码
  getPreference (field) {
    if (!this.isTest) {
      if(navigator.userAgent.match('iPad') || navigator.userAgent.match('iPhone')){
        return JSON.parse(window.prompt("getPreference",field)).data
      } else {
        return HostApp.getPreference(field).data
      }
    } else {
      return this.context[field]
    }
  },

  // 删除文件
  delfile: function (fileName) {
    if (this.isTest) {
    } else {
      if(navigator.userAgent.match('iPad') || navigator.userAgent.match('iPhone')){
        window.prompt("delfile",fileName);
      } else {
        HostApp.delfile(fileName)
      }
    }
  },
  //拨打电话
  makeAPhoneCall: function(phoneNumber) {
    if (this.isTest) {
    } else {
      if(navigator.userAgent.match('iPad') || navigator.userAgent.match('iPhone')){
        window.prompt("makeAPhoneCall",phoneNumber);
      } else {
        HostApp.makeAPhoneCall(phoneNumber)
      }
    }
  },
  // 拍照后，回传参数获取
  // self: 调用时的组件
  getCallBack: function (self) {
    if (this.isTest) {
      return self
    } else {
      if(navigator.userAgent.match('iPad') || navigator.userAgent.match('iPhone')){
        let self = window.iosApp.__this__;
        window.iosApp.__callback__ = null;
        window.iosApp.__this__ = null;
        return self;
      } else {
        let self = HostApp.__this__;
        HostApp.__callback__ = null;
        HostApp.__this__ = null;
        return self;
      }
    }
  },
  // 签名IOS调用
  // fileName: 文件名
  getSignIos: function (fileName,signData) {
    if(navigator.userAgent.match('iPad') || navigator.userAgent.match('iPhone')){
      let data = {
        name:fileName,
        source:signData
      }
      let result = window.prompt("__savesign__",JSON.stringify(data))
      return result;
  }
},
  // 获取移动设备IMEI码
  getDeviceIEMI: function () {
    if (this.isTest)
      return "20190521000010002";
    else
    if(navigator.userAgent.match('iPad') || navigator.userAgent.match('iPhone')){
      return JSON.parse(window.prompt("getFullFileName",fileName)).data;
    } else {
      return HostApp.getDeviceInfo().data
    }
  },

  // 拍照
  // self: 进行拍照的组件
  takePic: function (self, callback, fileName,sutitle) {
    if (this.isTest) {
      // HostApp.__callback__ = self.cameraCallBack
      // HostApp.__this__ = self
      // prop代表给那个部分进行拍照
      let prop = 'repair';
      let idx = 'aofeng';
      let title = sutitle ? sutitle :'维修拍照';
      // 维修人名称
      let name = Vue.user.name;
      // 模拟调用参数
      let result = {
        type: 'boomerang',
        page: 'com.aofeng.hybrid.android.peripheral.CameraActivity',
        param: {
          file: fileName,
          requestCode: 111,
          callback:'javascript:HostApp.__callback__("' + prop +'", "%s");',
          watermark: title + '\t时间：' + Util.toStandardTimeString() + '\t' + userame
        }
      };
      callback(prop, fileName);
      return result
      // HostApp._open_a_page()
    } else {
      if(navigator.userAgent.match('iPad') || navigator.userAgent.match('iPhone')){
        window.iosApp.__callback__ = callback;
        window.iosApp.__this__ = self;
        // prop代表给那个部分进行拍照
        let prop = 'repair';
        let idx = 'aofeng';
        let title = sutitle ? sutitle :'维修拍照';
        // 维修人名称
        let repairname = Vue.user.name;
        window.prompt("_open_a_page",JSON.stringify({type: 'boomerang',
          page: 'com.aofeng.hybrid.android.peripheral.CameraActivity',
          param: {
            file: fileName,
            requestCode: 111,
            callback:'javascript:this.iosApp.__callback__("' + prop +'", "%s");',
            watermark: title + '\t时间：' + Util.toStandardTimeString() + '\t' + repairname
          }
        }));
      } else {
        HostApp.__callback__ = callback;
        HostApp.__this__ = self;
        // prop代表给那个部分进行拍照
        let prop = 'repair';
        let idx = 'aofeng';
        let title = sutitle ? sutitle :'维修拍照';
        // 维修人名称
        console.log(`维修人名称:${Vue.user.name}`)
        let repairname = Vue.user.name;
        HostApp._open_a_page({type: 'boomerang',
          page: 'com.aofeng.hybrid.android.peripheral.CameraActivity',
          param: {
            file: fileName,
            requestCode: 111,
            callback:'javascript:HostApp.__callback__("' + prop +'", "%s");',
            watermark: title + '\t时间：' + Util.toStandardTimeString() + '\t' + repairname
          }
        })
      }
    }
  }
}
