import Vue from 'vue'

export default class DataModel {
  // 用url及pageSize构造
  // url - 加载数据的url
  // params - 除正常查询条件外，附加到后台sql中的参数，可以为空。格式为:{参数名:参数值}
  constructor (url, params) {
    this.url = url

    // 登记参数源码，查询前，执行参数源码，获得实际参数值
    if (params) {
      this.paramSource = params
    }
    // 查询时，提交后台的参数值
    this.params = {}

    // 状态，字符串型，包括：初始(默认)，查询，错误，正确
    this.state = '初始'
    // 出现错误时的错误内容，没找到符合条件的数据当错误处理
    this.error = '请输入条件, 进行查询'

    // 每次加载所需要的条件
    this.condition = null
    this.model = null

    // 获取到的数据
    this.data = null
  }

  // 执行查询过程，加载数据汇总信息
  // condition - 查询组件产生的查询条件
  // model - 查询组件收集到的输入数据
  search (condition, model) {
    // 保存条件，以便加载某页时可以直接调用
    this.condition = condition
    this.model = model

    this.state = '查询'
    this.procParams()

    // 发生请求时，不进行任何提醒
    return Vue.resetpost(`${this.url}`, {data: this.params}, {resolveMsg: null, rejectMsg: null}).then(
      (response) => {
        this.state = '正确'
        this.data = response.data
      }
    ).catch(
      () => {
        this.state = '错误'
        this.error = '提取数据出错，请重试'
      }
    )
  }

  // 处理查询参数，把condition附加到参数列表中
  procParams () {
    this.params.condition = this.condition
    if (!this.paramSource) {
      return
    }
    // 对附加参数进行计算
    for (let name in this.paramSource) {
      /*eslint-disable */
      let val = eval(this.paramSource[name])
      /*eslint-enable */
      this.params[name] = val
    }
  }
}
