import Vue from 'vue'

let id = 0

const createElm = function () {
  const elm = document.createElement('div')

  elm.id = 'app' + ++id
  document.body.appendChild(elm)

  return elm
}

export default {
  // 创建一个测试组件
  createTest: function (name, props) {
    const Constructor = Vue.extend(name)
    const elm = createElm()
    // this.procProps(props)
    const vm = new Constructor({el: elm, propsData: props})
    // Object.assign(vm, props)
    // vm.$mount(elm)
    return vm
  },

  // 创建一个异步组件，组件必须发出ready或者error事件
  createAsyncTest (name, props) {
    return new Promise((resolve, reject) => {
      let vm = this.createTest(name, props)
      vm.$on('ready', () => {
        resolve(vm)
      })
      vm.$on('error', (error) => {
        reject(error)
      })
    })
  },

  // 删除一个组件
  destroyVM: function (vm) {
    vm.$destroy && vm.$destroy()
    vm.$el &&
    vm.$el.parentNode &&
    vm.$el.parentNode.removeChild(vm.$el)
  },

  /**
   * 触发一个事件
   * mouseenter, mouseleave, mouseover, keyup, change, click 等
   * @param  {Element} elm
   * @param  {String} name
   * @param  {*} opts
   */
  triggerEvent: function (elm, name, ...opts) {
    let eventName

    if (/^mouse|click/.test(name)) {
      eventName = 'MouseEvents'
    } else if (/^key/.test(name)) {
      eventName = 'KeyboardEvent'
    } else {
      eventName = 'HTMLEvents'
    }
    const evt = document.createEvent(eventName)

    evt.initEvent(name, ...opts)
    elm.dispatchEvent
      ? elm.dispatchEvent(evt)
      : elm.fireEvent('on' + name, evt)

    return elm
  }
}
