﻿import Vue from 'vue'
import Validator from 'vue-validator'
Vue.use(Validator)
// 自定义验证器
// 多验证器用法：v-validate:属性名="['valid1','valid2']"
// 带参用法：v-validate:属性名="{valid1: [model.k, model.props2]}"
// 添加一个手机号验证
// 匹配0-9之间的数字,并且长度是11位
Vue.validator('telphoneValid', function (val) {
  // 验证规则：11位数字，以1开头
  return /^1\d{10}$/.test(val)
})
// 添加一个密码验证
Vue.validator('passwordValid', function (val) {
  // 验证规则：6-18位必须由字母、数字组成可包含下划线
  // return /^(?![0-9]+$)(?![a-zA-Z]+$)[0-9A-Za-z_]{6,18}$/.test(val)
  // 验证规则：6-18位字母、数字、下划线组成
  return /^[a-zA-Z0-9_]{6,18}$/.test(val)
})
// 添加一个重复密码验证
Vue.validator('equalValid', function (val, val2) {
  // 验证规则：两次密码输入是否一致
  if (val === val2) {
    return true
  }
  return false
})
// 添加一个验证码验证
Vue.validator('validValid', function (val) {
  // 验证规则：4位数字组成
  return /^\d{4}$/.test(val)
})
// 添加一个卡号验证
Vue.validator('cardValid', function (val) {
  // 验证规则：10位数字组成
  return /^\d{10}$/.test(val)
})
// 添加一个限购验证
Vue.validator('allowValid', function (val, allow) {
  // 验证规则：输入值不可大于限购值
  if ((val > 0) && (val <= allow)) {
    return true
  }
  return false
})
// 添加一个下限验证
Vue.validator('downValid', function (val, allow) {
  // 验证规则：输入值不可大于限购值
  if ((val > 0) && (val >= allow)) {
    return true
  }
  return false
})
// 整数验证
Vue.validator('integernum', function (val) {
  return /^[0-9]*[1-9][0-9]*$/.test(val)
})
// 添加一个邮箱验证
Vue.validator('emailValid', function (val) {
  // 验证规则：姑且把邮箱地址分成“第一部分@第二部分”
  // 第一部分：由字母、数字、下划线、短线“-”、点号“.”组成
  // 第二部分：为一个域名，域名由字母、数字、短线“-”、域名后缀组成
  // 而域名后缀一般为.xxx或.xxx.xx，一区的域名后缀一般为2-4位，如cn,com,net
  return /^(\w-*\.*)+@(\w-?)+(\.\w{2,})+$/.test(val)
})
// 添加一个身份证号验证
Vue.validator('identityCardValid', function (val) {
	// 验证规则：身份证18位
	//地区： [1-9]\d{5}
	//年的前两位： (18|19|([23]\d))            1800-2399
	//年的后两位： \d{2}
	//月份： ((0[1-9])|(10|11|12))
	//天数： (([0-2][1-9])|10|20|30|31)          闰年不能禁止29+
	//三位顺序码： \d{3}
	//校验码： [0-9Xx]
  return /^[1-9]\d{5}(18|19|([23]\d))\d{2}((0[1-9])|(10|11|12))(([0-2][1-9])|10|20|30|31)\d{3}[0-9Xx]$/.test(val)
})
// 计算表达式值
Vue.validator('equalNum', function (val, val2, val3, val4) {
  // 第一个值大于第二值为true
  return val > val2
})

// 正则表达式  val ：被检验的值  expression：正则表达式
Vue.validator('regularCheck', function (val, expression) {
  return expression.test(val)
})

// 测试
Vue.validator('dctest', function (val, val2) {
  // 第一个值大于第二值为true
  if (val && val2) {
    val = val + ''
    return eval(`${val - 0}${val2[1]}${val2[0] - 0}`)
  }
  return false
})
