import Vue from 'vue'
import all from 'src/all'
import co from 'co'
import trans from 'src/trans/Trans'

let testGen = function * (done) {
  try {
    yield Vue.resetpost('http://1', {})
  } catch (error) {
    done()
  }
}

let test = async function (done) {
  try {
    await Vue.resetpost('http://1', {})
  } catch (error) {
    done()
  }
}

describe('HttpReset: 发送请求', () => {
  before( async () => {
    all()
    await trans.begin()
  })

  after( async () => {
    // 回滚事务
    await trans.rollback()
  })

  it('请求异常，await', done => {
    test(done)
  })

  it('请求异常，co', done => {
    let gen = testGen(done)
    co(gen)
  })

  it('发送错误Token', async function() {
    Vue.$login = {jwt: 'aaaa'}
    try {
      await Vue.resetpost('/rs/report/card_bill', {"data": {"condition":"53"}}, { rejectMsg: null, resolveMsg: null })
    } catch (error) {
      assert.equal(error.status, 500)
      assert.isAbove(error.data.length, 200)
    }
  })

  it('发送跨域请求', async function() {
    Vue.$login = {jwt: 'aaaa'}
    try {
      await Vue.resetpost('http://127.0.0.1:8003/test', {data: {}}, { rejectMsg: null, resolveMsg: null })
    } catch (error) {
      assert.equal(error.status, 612)
      assert.isAbove(error.data.length, 0)
    }
  })

  it('客户端事务控制', async function() {
    try {
      // 开启事务，获得id号
      await Vue.resetpost('rs/logic/GenCallInPlan', {data: {
          "f_checker": "惠佳旭",
          "f_checker_id": "103624",
          "f_create_operator": "孙正忠",
          "f_create_time": "2020-04-25 16:06:06",
          "f_effective_end_time": "2020-04-25 16:06:06",
          "f_effective_start_time": "2020-04-25 16:06:06",
          "f_filialeid": "453",
          "f_issued": "否",
          "f_plan_month": "4",
          "f_plan_name": "这里",
          "f_plan_type": "预约计划",
          "f_plan_year": "2020",
          "strids": "29,31,30"
        }}, { rejectMsg: null, resolveMsg: null })
    } catch (error) {
      assert.equal(error.status, 612)
      assert.isAbove(error.data.length, 0)
    } finally {
    }
  })

})

// also see example testing a component with mocks at
// https://github.com/vuejs/vue-loader-example/blob/master/test/unit/a.spec.js#L24-L49
